@@ -156,24 +156,48 @@ class Parser:
       return self.parse_declaration(parent, node.children[1], decorators)
     return None
 
+  def _split_statement(self, stmt):
+    """
+    Parses a statement node into three lists, consisting of the leaf nodes
+    that are the name(s), annotation and value of the expression. The value
+    list will be empty if this is not an assignment statement (but for example
+    a plain expression).
+    """
+
+    def _parse(stack, current, stmt):
+      for child in stmt.children:
+        if not isinstance(child, Node) and child.value == '=':
+          stack.append(current)
+          current = ('value', [])
+        elif not isinstance(child, Node) and child.value == ':':
+          stack.append(current)
+          current = ('annotation', [])
+        elif isinstance(child, Node) and child.type == syms.annassign:
+          _parse(stack, current, child)
+        else:
+          current[1].append(child)
+      stack.append(current)
+      return stack
+
+    result = dict(_parse([], ('names', []), stmt))
+    return result.get('names', []), result.get('annotation', []), result.get('value', [])
+
   def parse_statement(self, parent, stmt):
-    is_assignment = False
-    names = []
-    expression = []
-    for child in stmt.children:
-      if not isinstance(child, Node) and child.value == '=':
-        is_assignment = True
-        names.append(expression)
-        expression = []
-      else:
-        expression.append(child)
-    if is_assignment:
+    names, annotation, value = self._split_statement(stmt)
+    if value or annotation:
       docstring = self.get_statement_docstring(stmt)
-      expr = Expression(self.nodes_to_string(expression))
+      expr = Expression(self.nodes_to_string(value)) if value else None
+      annotation = Expression(self.nodes_to_string(annotation)) if annotation else None
       assert names
       for name in names:
-        name = self.nodes_to_string(name)
-        data = Data(self.location_from(stmt), parent, name, docstring, expr=expr)
+        name = self.nodes_to_string([name])
+        data = Data(
+          self.location_from(stmt),
+          parent,
+          name,
+          docstring,
+          expr=expr,
+          annotation=annotation)
       return data
     return None
 
@@ -571,7 +595,7 @@ class PythonLoader(Struct):
 
   #: The "print_function" flag will be passed down to the lib2to3
   #: RefactoringTool. This enables parsing Python 3 code that uses the
-  #: print function without importing importing print_function from the
+  #: print function without importing the print_function from the
   #: `__future__` module.
   print_function = Field(bool, default=True)
 
@@ -605,7 +629,10 @@ class PythonLoader(Struct):
           full_path = os.path.join(path, name, '__init__.py')
           if os.path.isfile(full_path) and name not in self.IGNORE_DISCOVERED_MODULES:
             packages.append(name)
-      logger.info('Detected packages in search_path: %s', packages)
+      if not modules and not packages:
+        logger.warning('No Python modules or packages detected.')
+      else:
+        logger.info('Detected packages in search_path: %s', packages)
     else:
       modules = self.modules or []
       packages = self.packages or []
