@@ -59,7 +59,7 @@ class MarkdownRenderer(Struct):
 
   #: Generate descriptive class titles by adding the word "Objects" after
   #: the class name. This is enabled by default.
-  descriptive_class_title = Field(bool, default=False)
+  descriptive_class_title = Field(bool, default=True)
 
   #: Generate descriptivie module titles by adding the word "Module" before
   #: the module name. This is enabled by default.
@@ -96,7 +96,7 @@ class MarkdownRenderer(Struct):
   classdef_code_block = Field(bool, default=True)
 
   #: Render the constructor signature in the class definition code block
-  #: if it's `__init__()` member is not visible.
+  #: if its `__init__()` member is not visible.
   classdef_render_init_signature_if_needed = Field(bool, default=True)
 
   #: Render classdef and function signature blocks in the Python help()
@@ -145,8 +145,8 @@ class MarkdownRenderer(Struct):
 
   #: Fixed header levels by API object type.
   header_level_by_type = Field({int}, default={
-    'Module': 2,
-    'Class': 3,
+    'Module': 1,
+    'Class': 2,
     'Method': 4,
     'Function': 4,
     'Data': 4,
